@@ -27,6 +27,8 @@ public:
   Vertex getCenter(int ix, int iz);  
   virtual void getShapeName(char* buffer, int buflen) { strncpy(buffer, "surface", buflen); };
   
+  int getAttributeCount(AABox& bbox, AttribID attrib);
+  void getAttribute(AABox& bbox, AttribID attrib, int first, int count, double* result);
   
   virtual int getElementCount(void) { return (nx-1)*(nz-1); }
   
